@@ -3,6 +3,10 @@ use r2d2_oracle::OracleConnectionManager;
 use r2d2::{Pool, PooledConnection};
 use parking_lot::{ RwLock};
 use std::time::Duration;
+use serde::{Serialize};
+use std::fmt::{Display, Formatter, Result as FmtResult};
+use serde_json::{to_string_pretty};
+
 use crate::{DB_PROPERTIES};
 
 lazy_static!{
@@ -61,6 +65,27 @@ pub fn create_oracle_connection_manager() -> Pool<OracleConnectionManager> {
     pool
 }
 
+#[derive(Debug, Serialize)]
+pub enum OraDaoError {
+
+    ConnectionError(String),
+
+    StatementError(String),
+
+    QueryError(String),
+
+    RedisError(String),
+
+}
+
+impl Display for OraDaoError {
+    fn fmt(&self, f: &mut Formatter) -> FmtResult {
+        let error = to_string_pretty(self).unwrap();
+        error!("{}", &error);
+        write!(f, "{}", error)
+    }
+}
+
 #[cfg(test)]
 mod tests{
 }
\ No newline at end of file
